from setuptools import setup

setup(
    name='Albot.Online',
    version='0.62',
    packages=['AlbotOnline', 'AlbotOnline.Snake', 'AlbotOnline.BrickPuzzle', 'AlbotOnline.Connect4', 'AlbotOnline.Tests', 'AlbotOnline.QueueFlowServiceControl'],
    url='https://www.albot.online/',
    license='MIT',
    author='Albot.Online',
    author_email='Albot.Online.info@gmail.com',
    description='A simple library for connecting you and supplying game functions for  the Albot.Onlie Client.'
)
